@@ -1,39 +1,39 @@
 #' Produce all combinations of list elements
 #'
-#' \code{cross2()} returns the product set of the elements of
-#' \code{.x} and \code{.y}. \code{cross3()} takes an additional
-#' \code{.z} argument. \code{cross_n()} takes a list \code{.l} and
+#' `cross2()` returns the product set of the elements of
+#' `.x` and `.y`. `cross3()` takes an additional
+#' `.z` argument. `cross()` takes a list `.l` and
 #' returns the cartesian product of all its elements in a list, with
-#' one combination by element. \code{cross_d()} is like
-#' \code{cross_n()} but returns a data frame, with one combination by
+#' one combination by element. `cross_df()` is like
+#' `cross()` but returns a data frame, with one combination by
 #' row.
 #'
-#' \code{cross_n()}, \code{cross2()} and \code{cross3()} return the
+#' `cross()`, `cross2()` and `cross3()` return the
 #' cartesian product is returned in wide format. This makes it more
-#' amenable to mapping operations. \code{cross_d()} returns the output
-#' in long format just as \code{expand.grid()} does. This is adapted
+#' amenable to mapping operations. `cross_df()` returns the output
+#' in long format just as `expand.grid()` does. This is adapted
 #' to rowwise operations.
 #'
 #' When the number of combinations is large and the individual
 #' elements are heavy memory-wise, it is often useful to filter
-#' unwanted combinations on the fly with \code{.filter}. It must be
+#' unwanted combinations on the fly with `.filter`. It must be
 #' a predicate function that takes the same number of arguments as the
-#' number of crossed objects (2 for \code{cross2()}, 3 for
-#' \code{cross3()}, \code{length(.l)} for \code{cross_n()}) and
-#' returns \code{TRUE} or \code{FALSE}. The combinations where the
-#' predicate function returns \code{TRUE} will be removed from the
+#' number of crossed objects (2 for `cross2()`, 3 for
+#' `cross3()`, `length(.l)` for `cross()`) and
+#' returns `TRUE` or `FALSE`. The combinations where the
+#' predicate function returns `TRUE` will be removed from the
 #' result.
-#' @seealso \code{\link{expand.grid}()}
+#' @seealso [expand.grid()]
 #' @param .x,.y,.z Lists or atomic vectors.
 #' @param .l A list of lists or atomic vectors. Alternatively, a data
-#'   frame. \code{cross_d()} requires all elements to be named.
+#'   frame. `cross_df()` requires all elements to be named.
 #' @param .filter A predicate function that takes the same number of
 #'   arguments as the number of variables to be combined.
-#' @return \code{cross2()}, \code{cross3()} and \code{cross_n()}
-#'   always return a list. \code{cross_d()} always returns a data
-#'   frame. \code{cross_n()} returns a list where each element is one
+#' @return `cross2()`, `cross3()` and `cross()`
+#'   always return a list. `cross_df()` always returns a data
+#'   frame. `cross()` returns a list where each element is one
 #'   combination so that the list can be directly mapped
-#'   over. \code{cross_d()} returns a data frame where each row is one
+#'   over. `cross_df()` returns a data frame where each row is one
 #'   combination.
 #' @export
 #' @examples
@@ -46,18 +46,18 @@
 #' )
 #'
 #' data %>%
-#'   cross_n() %>%
+#'   cross() %>%
 #'   map(lift(paste))
 #'
-#' # cross_n() returns the combinations in long format: many elements,
-#' # each representing one combination. With cross_d() we'll get a
+#' # cross() returns the combinations in long format: many elements,
+#' # each representing one combination. With cross_df() we'll get a
 #' # data frame in long format: crossing three objects produces a data
 #' # frame of three columns with each row being a particular
 #' # combination. This is the same format that expand.grid() returns.
-#' args <- data %>% cross_d()
+#' args <- data %>% cross_df()
 #'
 #' # In case you need a list in long format (and not a data frame)
-#' # just run as.list() after cross_d()
+#' # just run as.list() after cross_df()
 #' args %>% as.list()
 #'
 #' # This format is often less pratical for functional programming
@@ -84,14 +84,14 @@
 #' # before crossing to get named components:
 #' seq_len(3) %>%
 #'   list(x = ., y = .) %>%
-#'   cross_n(.filter = `==`)
-cross_n <- function(.l, .filter = NULL) {
+#'   cross(.filter = `==`)
+cross <- function(.l, .filter = NULL) {
   if (is_empty(.l)) {
     return(.l)
   }
 
   if (!is.null(.filter)) {
-    .filter <- as_function(.filter)
+    .filter <- as_mapper(.filter)
   }
 
   n <- length(.l)
@@ -130,22 +130,40 @@ cross_n <- function(.l, .filter = NULL) {
 }
 
 #' @export
-#' @rdname cross_n
+#' @rdname cross
 cross2 <- function(.x, .y, .filter = NULL) {
-  cross_n(list(.x, .y), .filter = .filter)
+  cross(list(.x, .y), .filter = .filter)
 }
 
 #' @export
-#' @rdname cross_n
+#' @rdname cross
 cross3 <- function(.x, .y, .z, .filter = NULL) {
-  cross_n(list(.x, .y, .z), .filter = .filter)
+  cross(list(.x, .y, .z), .filter = .filter)
 }
 
-#' @rdname cross_n
+#' @rdname cross
 #' @export
-cross_d <- function(.l, .filter = NULL) {
-  cross_n(.l, .filter = .filter) %>%
+cross_df <- function(.l, .filter = NULL) {
+  cross(.l, .filter = .filter) %>%
     transpose() %>%
     simplify_all() %>%
-    dplyr::as_data_frame()
+    tibble::as_tibble()
+}
+
+#' @export
+#' @usage NULL
+#' @rdname cross
+cross_n <- function(...) {
+  warning("`cross_n()` is deprecated; please use `cross()` instead.",
+    call. = FALSE)
+  cross(...)
+}
+
+#' @export
+#' @usage NULL
+#' @rdname cross
+cross_d <- function(...) {
+  warning("`cross_d()` is deprecated; please use `cross_df()` instead.",
+    call. = FALSE)
+  cross_df(...)
 }
